function Dis = Main_analytical_model_paper
% This function calculates the total received power analytically for flat, and spherical reflectors using the formulas in the paper.

clear all
close all

f = 28e9;                                           % Operating frequency
P_T = 1e-3;                                         % Transmit power
G_T = 10^1.7;                                       % Gain of transmit antenna
G_R = G_T;                                          % Gain of receive antenna
lambda = 3e8/f;                                     % Wavelength

Mat = {};
A_core = .25^2;                                     % Core area
A_cylinder = (15*(pi/180)*.106*.25)/A_core;         % Area of cylinder
A_sphere = .0219;                                   % Area of sphere
% As the area of the reflectors is greater than core area therefore, taking core area as the operational area

N1 = 5; N2 = 50; ind2 = 3;                                    % Dimensions of the receiver grid from the RHS

% Grid positioning
for ii = 1:N2
    ind1=0;Mat = {};
    if(ii>1)
        ind2 = ind2 + 0.3;
    end
    for jj = 1:N1
        ind1 = ind1 + 0.3;
        
        Mat{jj} = [ind1,ind2];
    end
    Mat_cell{ii} = Mat;
end

theta = zeros(N1,N2); alpha = 0.72; alpha2 = 0.85; Decay_temp = zeros(N1,N2); Decay_temp2 = zeros(N1,N2); Dis_temp = zeros(N1,N2);          % alpha values for flat and sphereical reflectors as provided in the paper

% Power decay calculation according to formula in the paper
for ii = 1:N2
    for jj = 1:N1
        theta(jj,ii) = atand(Mat_cell{ii}{jj}(2)/Mat_cell{ii}{jj}(1));                  % delta theta in the paper
        Decay_temp(jj,ii) = (alpha^(90-theta(jj,ii)));                                  % delta theta (change in the azimuth plane) in the paper
        Decay_temp2(jj,ii) = (alpha2^(90-theta(jj,ii)));
        Dis_temp(jj,ii) = sqrt(Mat_cell{ii}{jj}(1)^2 + Mat_cell{ii}{jj}(2)^2);          % Distance on the receiver grid
    end
end

Decay = Decay_temp.';
Decay(:,1)=1;                                                                           % No decay across first receiver grid column due to perfect orientation of reflector across it (From paper)
Decay2 = Decay_temp2.';
Decay2(:,1)=1;
Dis = Dis_temp.';

Rx_power = zeros(size(Dis)); Rx_power_cylinder = zeros(size(Dis));
P_s = 1e-10;                                                                            % Corresponding to -70 dBm for the no reflector case (From measurements, given in the paper)

% Receive power calculation for flat and spherical reflectors
for ii = 1:N2
    for jj = 1:N1
        Num = (P_T*G_T*G_R*lambda^2*Decay(ii,jj));
        Denom = (4*pi*(sqrt(4^2+Dis(ii,jj)^2))).^2;
        Rx_power(ii,jj) = (Num/Denom) + P_s;
        Num_cylinder = P_T*G_T*G_R*lambda^2;
        Rx_power_cylinder(ii,jj) = (Num_cylinder*A_cylinder*Decay2(ii,jj))/Denom + P_s;
        Rx_power_sphere(ii,jj) = (Num_cylinder*A_sphere*Decay2(ii,jj))/Denom + P_s;
    end
end

% Converting power to dBm
Rx_power_dbm = 10*log10(Rx_power/1e-3);
Rx_power_cylinder_dbm = 10*log10(Rx_power_cylinder/1e-3);
Rx_power_sphere_dbm = 10*log10(Rx_power_sphere/1e-3);


orien_pw = 3;                                                                             % Diffraction loss beta (From paper)


%% Plotting
fig = figure

% For .30 x .30 m reflector
subplot(1,2,1)
imagesc((1:5)*0.3, (0:2:51)*.3,fliplr(Rx_power_dbm-orien_pw));                              % Subtraction of diffraction losses only for the .30 x .30 m reflector
colormap(jet(1000))
c = colorbar
xlabel({'x [m]'}); ylabel('y [m]')
ylabel(c,'dBm');
title('Analytical')
ax = gca
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
%ylabel(c,'dBm')
caxis([-87.5497 -41.3866])
set(gca,'Fontsize',20)
orient(fig,'landscape')
set(fig, 'PaperType', 'uslegal');


% For .61 x .61 m reflector                                                                 % Similar for the .84 x .84 m reflector
subplot(1,2,2)
imagesc((1:5)*0.3, (0:2:51)*.3,fliplr(Rx_power_dbm));
colormap(jet(1000))
c = colorbar
xlabel({'x [m]'}); ylabel('y [m]')
ylabel(c,'dBm');
title('Analytical')
ax = gca
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
%ylabel(c,'dBm')
caxis([-87.5497 -41.3866])
set(gca,'Fontsize',20)
orient(fig,'landscape')
set(fig, 'PaperType', 'uslegal');

% For sphere
fig = figure
subplot(1,2,1)
imagesc((1:5)*0.3, (0:2:51)*.3,fliplr(Rx_power_sphere_dbm));
colormap(jet(1000))
c = colorbar
xlabel({'x [m]'}); ylabel('y [m]')
ylabel(c,'dBm');
title('Analytical')
ax = gca
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
%ylabel(c,'dBm')
caxis([-87.5497 -41.3866])
set(gca,'Fontsize',20)
orient(fig,'landscape')
set(fig, 'PaperType', 'uslegal');

% For cylinder
subplot(1,2,2)
imagesc((1:5)*0.3, (0:2:51)*.3,fliplr(Rx_power_cylinder_dbm));
colormap(jet(1000))
c = colorbar
xlabel({'x [m]'}); ylabel('y [m]')
ylabel(c,'dBm');
title('Analytical')
ax = gca
ax.XTick = [0.3 0.6 0.9 1.2 1.5];
ax.YTick = [0 3 6 9 12 15];
%ylabel(c,'dBm')
caxis([-87.5497 -41.3866])
set(gca,'Fontsize',20)
orient(fig,'landscape')
set(fig, 'PaperType', 'uslegal');

%rx_anyl_12 = 0; rx_anlyl_24 =0; rx_anyl_sp = 0; rx_anyl_cyl = 0;
%rx_temp = Rx_power_dbm-orien_pw;
%save('rx_anyl_12.mat');
%save('anyl_12.mat','rx_temp');
%save('anyl_24.mat','Rx_power_dbm');
%save('anly_sph.mat','Rx_power_sphere_dbm');
%save('anyl_cyl.mat','Rx_power_cylinder_dbm');



%% CDF of received power plotting
% CDF plots for flat sheet reflectors

pwr_0_3 = Rx_power_dbm-orien_pw;
pwr_0_6=Rx_power_dbm;
pwr_sphere=Rx_power_sphere_dbm;
pwr_cylinder=Rx_power_cylinder_dbm;

col = {'b','g','m','c','k'};

%close all
figure
hold on
temp = reshape(pwr_0_3,[size(pwr_0_3,1)*size(pwr_0_3,2),1]);
h1 = cdfplot(temp(1:1:end))
temp = reshape(pwr_0_6,[size(pwr_0_6,1)*size(pwr_0_6,2),1]);
h2 = cdfplot(temp(1:1:end))
temp = reshape(pwr_sphere,[size(pwr_sphere,1)*size(pwr_sphere,2),1]);
h3 = cdfplot(temp(1:1:end))
temp = reshape(pwr_cylinder,[size(pwr_cylinder,1)*size(pwr_cylinder,2),1]);
h4 = cdfplot(temp(1:1:end))


fig=figure
hold on
line_fewer_markers(h1.XData, h1.YData, 10, 'm- +', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{1})
line_fewer_markers(h2.XData, h2.YData, 10, 'm- >', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{2})
line_fewer_markers(h3.XData, h3.YData, 10, 'm- s', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{3})
line_fewer_markers(h4.XData, h4.YData, 10, 'm- p', 'MarkerSize', 8.5, 'LineWidth', 2, 'Color', col{4})


xlabel({'Received power (dBm)'})
ylabel('CDF')
legend('Analytical .30mx.30m reflector', 'Analytical .61mx.61m reflector','Analytical sphere','Analytical cylinder');
legend(gca,'location','NorthWest')
orient(fig,'landscape')
set(fig, 'PaperType', 'uslegal');
set(gca,'Fontsize',14)
xlim([-97 -40])
set(gcf, 'Position',  [200, 50, 800, 600])
yticks([0 0.2 0.4 0.6 0.8 1])
xticks([-90 -80 -70 -60 -50 -40])
